@@ -237,19 +237,6 @@ typedef int DMC_Bool;
 
 typedef BOOL (UsrFunc)(void);
 
-typedef struct {
-	Byte*	GroupName;
-	Byte*	DefLangName;
-	BOOL	bBigEndian;
-	DWord	Option;
-	DWord	Option1;
-	Long	Size;
-		// DWord -> Long 2006.05.24 Takeshi Yoneki
-	Word	Csv_c;
-	UsrFunc *pFunc;
-} DMC_TEXTINFO, *LPDMC_TEXTINFO;
-
-//typedef BOOL (UsrFunc)(void);
 typedef struct {
 	Byte	GroupName[MAX_GROUP_NAME];
 	Byte	DefLangName[MAX_LANG_NAME];
@@ -262,6 +249,16 @@ typedef struct {
 	//UsrFunc *pFunc;
 } DMC_TEXTINFO_V4, *LPDMC_TEXTINFO_V4;
 
+typedef struct {
+	Byte	GroupName[MAX_GROUP_NAME];
+	Byte	DefLangName[MAX_LANG_NAME];
+	BOOL	bBigEndian;
+	DWord	Option;
+	DWord	Option1;
+	Long	Size;
+	Word	Csv_c;
+} DMC_TEXTINFO_V5, *LPDMC_TEXTINFO_V5;
+
 #define DMC_GETTEXT_OPT_KEISEN	0x00000001
 #define DMC_GETTEXT_OPT_TAG		0x00000002
 #define DMC_GETTEXT_OPT_RUBI	0x00000004
@@ -359,10 +356,11 @@ typedef struct {
 #define	DTCT_WD2007MC	"Word 2007 with Macro"
 #define	DTCT_WD2007TP	"Word 2007 Template"
 #define	DTCT_WD2007MCTP	"Word 2007 Template with Macro"
-#define	DTCT_WD2010	"Word 2010"
-#define	DTCT_WD2010MC	"Word 2010 with Macro"
-#define	DTCT_WD2010TP	"Word 2010 Template"
-#define	DTCT_WD2010MCTP	"Word 2010 Template with Macro"
+#define DTCT_WD2010	"Word 2010"
+#define DTCT_WD2010MC	"Word 2010 with Macro"
+#define DTCT_WD2010TP	"Word 2010 Template"
+#define DTCT_WD2010MCTP	"Word 2010 Template with Macro"
+#define DTCT_WD2010ENC	"Word 2010 Encrypted"
 #define	DTCT_EXL4	"Excel Ver.4"
 #define	DTCT_EXL5	"Excel Ver.5/7(95)"
 #define	DTCT_EXL7	"Excel 97/2000/XP"
@@ -375,11 +373,11 @@ typedef struct {
 #define	DTCT_EXL2007TP	"Excel 2007 Template"
 #define	DTCT_EXL2007MCTP	"Excel 2007 Template with Macro"
 #define	DTCT_EXL2007MCBN	"Excel 2007 Binary with Macro"
-#define	DTCT_EXL2010	"Excel 2010"
-#define	DTCT_EXL2010MC	"Excel 2010 with Macro"
-#define	DTCT_EXL2010TP	"Excel 2010 Template"
-#define	DTCT_EXL2010MCTP	"Excel 2010 Template with Macro"
-#define	DTCT_EXL2010MCBN	"Excel 2010 Binary with Macro"
+#define DTCT_EXL2010	"Excel 2010"
+#define DTCT_EXL2010MC	"Excel 2010 with Macro"
+#define DTCT_EXL2010TP	"Excel 2010 Template"
+#define DTCT_EXL2010MCTP	"Excel 2010 Template with Macro"
+#define DTCT_EXL2010MCBN	"Excel 2010 Binary with Macro"
 #define	DTCT_PPT5	"PowerPoint 95"
 #define	DTCT_PPT7	"PowerPoint 97/2000/XP"
 #define	DTCT_PPT9	"Mac-PowerPoint 2001"
@@ -404,7 +402,7 @@ typedef struct {
 #define	DTCT_TARO5	"Ichitaro V5"
 #define	DTCT_TARO6	"Ichitaro V6"
 #define	DTCT_TARO7	"Ichitaro V7"
-#define	DTCT_TARO8	"Ichitaro 8/9/10/11/12/13/2004/2005/2006/2007"
+#define DTCT_TARO8	"Ichitaro Document"	// 2009.12.25 
 #define	DTCT_OASYS1	"OASYS Separated"
 #define	DTCT_OASYS2	"OASYS Combined"
 #define	DTCT_OASYS3	"OASYS Compound"
@@ -428,7 +426,9 @@ typedef struct {
 #define	DTCT_ACADR14DWG	"AutoCAD R14/LT97 DWG"
 #define	DTCT_ACAD2KDXF	"AutoCAD 2000 DXF"
 #define	DTCT_ACAD2KDXFBIN	"AutoCAD 2000 DXF BIN"
-#define	DTCT_ACAD2KDWG	"AutoCAD 2000/2002/2004/2005/2006 DWG"
+#define	DTCT_ACAD2KDWG	"AutoCAD 2000 DWG"
+#define	DTCT_ACAD2007DWG	"AutoCAD 2007 DWG"//2009/12/10 add
+#define	DTCT_ACAD2007DXF	"AutoCAD 2007 DXF"//2009/12/22 add
 #define	DTCT_QXD	"QuarkXPress"
 #define	DTCT_MACWRT	"Mac Write II"
 #define	DTCT_WP 	"Quattro Pro for Dos"
@@ -482,6 +482,12 @@ typedef struct {
 #define	DTCT_OPENOFFICE_IMPRESS "Open Office Impress 1.0"
 #define	DTCT_OPENOFFICE_MATH	"Open Office Math 1.0"
 #define	DTCT_OPENOFFICE_WRITER	"Open Office Writer 1.0"
+
+#define	DTCT_OPENOFFICE_V3_CALC		"Open Office V3.1 Calc"
+#define	DTCT_OPENOFFICE_V3_DRAW		"Open Office V3.1 Draw"
+#define	DTCT_OPENOFFICE_V3_PRESEN	"Open Office V3.1 Presentation"
+#define	DTCT_OPENOFFICE_V3_WRITER	"Open Office V3.1 Writer"
+
 #define	MultiEncodes	"Multi Charsets" //050927
 
 // DocSubFormat
@@ -627,7 +633,10 @@ typedef struct {
 
 /* File is not supported */
 #define CantDetectFile			2001
-#define NotSuppoted				2002
+// Xy~XCB݊̂߁A~XXŷ̂cĂB
+// 2010/04/16 by show
+#define NotSupported			2002
+#define NotSuppoted	NotSupported
 #define TimeOut					2003
 #define LanguageNotSupported	2004
 
@@ -643,23 +652,39 @@ typedef struct {
 
 /* OLE */
 #define OleCantDetectFile		4000
-#define OleNotSuppoted			4001
+// Xy~XCB݊̂߁A~XXŷ̂cĂB
+// ̃o[WAbvMRł͍폜B
+// 2010/04/16 by show
+#define OleNotSupported			4001
+#define OleNotSuppoted	OleNotSupported
 #define OleProtectedBypassWord	4002
 #define OleInvalidFile			4003
 #define OleNoTextStringFound	4004
 #define OleOutOfLimit			4005
 #define InsertFileOutOfLimit			4006
-#define InsertFileNotSuppoted			4007
+// Xy~XCB݊̂߁A~XXŷ̂cĂB
+// ̃o[WAbvMRł͍폜B
+// 2010/04/16 by show
+#define InsertFileNotSupported	4007
+#define InsertFileNotSuppoted	InsertFileNotSupported
 #define InsertFileNoTextStringFound			4008
 
 /* PWD */
 #define ProtectedByPassWordPDF	5000
 #define WrongPassWord			5001
-#define PWDfileNotSuppoted		5002
+// Xy~XCB݊̂߁A~XXŷ̂cĂB
+// ̃o[WAbvMRł͍폜B
+// 2010/04/16 by show
+#define PWDfileNotSupported		5002
+#define PWDfileNotSuppoted	PWDfileNotSupported
 #define ProtectedByOwnerPassWordPDF		5003
 
 #define CompressedFileCantDetect        6000
-#define CompressedFileNotSuppoted		6001
+// Xy~XCB݊̂߁A~XXŷ̂cĂB
+// ̃o[WAbvMRł͍폜B
+// 2010/04/16 by show
+#define CompressedFileNotSupported		6001
+#define CompressedFileNotSuppoted	CompressedFileNotSupported
 #define CompressedFileNoTextStringFound	6002
 #define CompressedFileInvalidfile		6003
 #define CompressedFileByPassWord		6004
@@ -694,27 +719,30 @@ typedef struct {
 
 typedef BOOL (*DMC_OLEERR_CALLBACK)(LDDMC_OLEERR* OleErr);
 
-#ifdef DMCSTREAM
-INT ToStreamDmc(Byte* Appfile,Byte* txtfile,DMC_TEXTINFO_V4* TextInfo);
-INT ToPageStreamDmc(Byte* Appfile,Byte* txtfile,DMC_TEXTINFO_V4* TextInfo,int* Pages);//quman 041213
+DMC_TXIF_EXPORT INT  DMC_GetFileInfo_V5(Byte* Appfile, DMC_FILEINFO* FileInfo, DMC_TEXTINFO_V5* TextInfo);
+DMC_TXIF_EXPORT INT  DMC_GetProperty_V5(Byte* Appfile, DMC_TEXTINFO_V5* TextInfo, DMC_PROPERTY* Property);
+DMC_TXIF_EXPORT INT  DMC_GetText_V5(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO_V5* TextInfo, DMC_OLEERR_CALLBACK pFuncOleErr);
+DMC_TXIF_EXPORT INT  DMC_GetPageText_V5(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO_V5* TextInfo, int* Pages, DMC_OLEERR_CALLBACK pFuncOleErr);
+DMC_TXIF_EXPORT INT  DMC_GetPwdText_V5(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO_V5* TextInfo, Byte* Password, DMC_OLEERR_CALLBACK pFuncOleErr);
+DMC_TXIF_EXPORT INT  DMC_GetPwdPageText_V5(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO_V5* TextInfo, int* Pages, Byte* Password, DMC_OLEERR_CALLBACK pFuncOleErr);
+DMC_TXIF_EXPORT INT  DMC_GetPwdProperty_V5(Byte* Appfile, DMC_TEXTINFO_V5* TextInfo, DMC_PROPERTY* Property, Byte* Password);
 
+#ifdef DMC_WIN
+DMC_TXIF_EXPORT INT  DMC_GetFileInfo_V5W(Word* Appfile, DMC_FILEINFO* FileInfo, DMC_TEXTINFO_V5* TextInfo);
+DMC_TXIF_EXPORT INT  DMC_GetProperty_V5W(Word* Appfile, DMC_TEXTINFO_V5* TextInfo, DMC_PROPERTY* Property);
+DMC_TXIF_EXPORT INT  DMC_GetText_V5W(Word* Appfile, Word* Txtfile, DMC_TEXTINFO_V5* TextInfo, DMC_OLEERR_CALLBACK pFuncOleErr);
+DMC_TXIF_EXPORT INT  DMC_GetPageText_V5W(Word* Appfile, Word* Txtfile, DMC_TEXTINFO_V5* TextInfo, int* Pages, DMC_OLEERR_CALLBACK pFuncOleErr);
+DMC_TXIF_EXPORT INT  DMC_GetPwdText_V5W(Word* Appfile, Word* Txtfile, DMC_TEXTINFO_V5* TextInfo, Byte* Password, DMC_OLEERR_CALLBACK pFuncOleErr);
+DMC_TXIF_EXPORT INT  DMC_GetPwdPageText_V5W(Word* Appfile, Word* Txtfile, DMC_TEXTINFO_V5* TextInfo, int* Pages, Byte* Password, DMC_OLEERR_CALLBACK pFuncOleErr);
+DMC_TXIF_EXPORT INT  DMC_GetPwdProperty_V5W(Word* Appfile, DMC_TEXTINFO_V5* TextInfo, DMC_PROPERTY* Property, Byte* Password);
 #endif
 
-
-DMC_TXIF_EXPORT INT  DMC_GetFileInfo_V3(Byte* Appfile, DMC_FILEINFO* FileInfo);
-DMC_TXIF_EXPORT INT  DMC_GetText_V3(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO* TextInfo);
-DMC_TXIF_EXPORT INT  DMC_GetPageText_V3(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO* TextInfo, int* Pages);
-DMC_TXIF_EXPORT INT  DMC_GetProperty_V3(Byte* Appfile, DMC_TEXTINFO* TextInfo, DMC_PROPERTY* Property);
-DMC_TXIF_EXPORT INT  DMC_GetPwdText_V3(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO* TextInfo, Byte* Password);
-DMC_TXIF_EXPORT INT  DMC_GetPwdPageText_V3(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO* TextInfo, int* Pages, Byte* Password);
-DMC_TXIF_EXPORT INT  DMC_GetPwdProperty_V3(Byte* Appfile, DMC_TEXTINFO* TextInfo, DMC_PROPERTY* Property, Byte* Password);
-
 DMC_TXIF_EXPORT INT  DMC_GetFileInfo_V4(Byte* Appfile, DMC_FILEINFO* FileInfo);
 DMC_TXIF_EXPORT INT  DMC_GetProperty_V4(Byte* Appfile, DMC_TEXTINFO_V4* TextInfo, DMC_PROPERTY* Property);
-DMC_TXIF_EXPORT INT  DMC_GetText_V4(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO_V4* TextInfo,DMC_OLEERR_CALLBACK pFuncOleErr);
-DMC_TXIF_EXPORT INT  DMC_GetPageText_V4(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO_V4* TextInfo, int* Pages,DMC_OLEERR_CALLBACK pFuncOleErr);
-DMC_TXIF_EXPORT INT  DMC_GetPwdText_V4(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO_V4* TextInfo, Byte* Password,DMC_OLEERR_CALLBACK pFuncOleErr);
-DMC_TXIF_EXPORT INT  DMC_GetPwdPageText_V4(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO_V4* TextInfo, int* Pages, Byte* Password,DMC_OLEERR_CALLBACK pFuncOleErr);
+DMC_TXIF_EXPORT INT  DMC_GetText_V4(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO_V4* TextInfo, DMC_OLEERR_CALLBACK pFuncOleErr);
+DMC_TXIF_EXPORT INT  DMC_GetPageText_V4(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO_V4* TextInfo, int* Pages, DMC_OLEERR_CALLBACK pFuncOleErr);
+DMC_TXIF_EXPORT INT  DMC_GetPwdText_V4(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO_V4* TextInfo, Byte* Password, DMC_OLEERR_CALLBACK pFuncOleErr);
+DMC_TXIF_EXPORT INT  DMC_GetPwdPageText_V4(Byte* Appfile, Byte* Txtfile, DMC_TEXTINFO_V4* TextInfo, int* Pages, Byte* Password, DMC_OLEERR_CALLBACK pFuncOleErr);
 DMC_TXIF_EXPORT INT  DMC_GetPwdProperty_V4(Byte* Appfile, DMC_TEXTINFO_V4* TextInfo, DMC_PROPERTY* Property, Byte* Password);
 
 
